==> colourvalues_0.3.0.tar.gz: colourvalues/inst/include/colourvalues/palettes/inferno.hpp <==
#ifndef R_COLOURVALUES_INFERNO_H
#define R_COLOURVALUES_INFERNO_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector inferno_red = {
    0.00146159096, 0.00226726368, 0.00329899092, 0.00454690615,
    0.00600552565, 0.00767578856, 0.00956051094, 0.0116634769, 0.0139950388,
    0.0165605595, 0.0193732295, 0.0224468865, 0.0257927373, 0.0294324251,
    0.0333852235, 0.0376684211, 0.0422525554, 0.0469146287, 0.0516437624,
    0.0564491009, 0.06133972, 0.066331262, 0.0714289181, 0.076636756,
    0.0819620773, 0.0874113897, 0.0929901526, 0.0987024972, 0.104550936,
    0.110536084, 0.116656423, 0.122908126, 0.129284984, 0.13577845,
    0.142377819, 0.149072957, 0.155849711, 0.162688939, 0.169575148,
    0.176493202, 0.183428775, 0.190367453, 0.197297425, 0.204209298,
    0.211095463, 0.217948648, 0.224762908, 0.231538148, 0.238272961,
    0.244966911, 0.251620354, 0.258234265, 0.264809649, 0.271346664,
    0.277849829, 0.284321318, 0.290763373, 0.297178251, 0.303568182,
    0.309935342, 0.316281835, 0.322609671, 0.328920763, 0.335216916,
    0.341499828, 0.347771086, 0.354032169, 0.360284449, 0.366529195,
    0.372767575, 0.379000659, 0.385228383, 0.391452659, 0.397674379,
    0.403894278, 0.410113015, 0.416331169, 0.422549249, 0.428767696,
    0.434986885, 0.441207124, 0.447428382, 0.453650614, 0.459874623,
    0.466100494, 0.472328255, 0.478557889, 0.484789325, 0.491022448,
    0.497257069, 0.503492698, 0.509729541, 0.515967304, 0.522205646,
    0.528444192, 0.534682523, 0.540920186, 0.547156706, 0.553391649,
    0.559624442, 0.565854477, 0.572081108, 0.578303656, 0.584521407,
    0.590733615, 0.596939751, 0.60313893, 0.609330184, 0.615512627,
    0.62168534, 0.627847374, 0.633997746, 0.640135447, 0.646259648,
    0.652369348, 0.658463166, 0.664539964, 0.670598572, 0.676637795,
    0.682656407, 0.688653158, 0.694626769, 0.700575937, 0.706499709,
    0.712396345, 0.718264447, 0.724102613, 0.729909422, 0.735683432,
    0.741423185, 0.747127207, 0.752794009, 0.75842209, 0.76400994,
    0.769556038, 0.775058888, 0.780517023, 0.785928794, 0.791292674,
    0.796607144, 0.801870689, 0.807081807, 0.812239008, 0.817340818,
    0.822385784, 0.827372474, 0.832299481, 0.837165425, 0.841968959,
    0.846708768, 0.851383572, 0.85599213, 0.860533241, 0.865005747,
    0.869408534, 0.87374053, 0.878000715, 0.882188112, 0.886301795,
    0.890340885, 0.894304553, 0.898192017, 0.902002544, 0.905735448,
    0.90939009, 0.912965874, 0.916462251, 0.91987871, 0.923214783,
    0.926470039, 0.929644083, 0.932736555, 0.935747126, 0.938675494,
    0.941521384, 0.944284543, 0.946964741, 0.949561766, 0.952075421,
    0.954505523, 0.956851903, 0.959114397, 0.96129285, 0.96338711,
    0.965397031, 0.967322465, 0.969163264, 0.970919277, 0.972590351,
    0.974176327, 0.975677038, 0.977092313, 0.978421971, 0.979665824,
    0.980823673, 0.981895311, 0.982880522, 0.983779081, 0.984590755,
    0.985315301, 0.985952471, 0.986502013, 0.98696367, 0.987337182,
    0.987622296, 0.987818759, 0.98792633, 0.987944783, 0.98787391,
    0.987713535, 0.987463516, 0.987123759, 0.986694229, 0.98617497,
    0.985565739, 0.984865203, 0.984075129, 0.983195992, 0.982228463,
    0.981173457, 0.980032178, 0.978806183, 0.977497453, 0.976108474,
    0.974637842, 0.973087939, 0.971467822, 0.969783146, 0.968040817,
    0.966242589, 0.964393924, 0.962516656, 0.960625545, 0.958720088,
    0.956834075, 0.954997177, 0.953215092, 0.951546225, 0.950018481,
    0.948683391, 0.947594362, 0.946809163, 0.946391536, 0.946402951,
    0.946902568, 0.947936825, 0.94954483, 0.951740304, 0.954529281,
    0.957896053, 0.96181202, 0.966248822, 0.971161622, 0.976510983,
    0.982257307, 0.988362068
  };

  const Rcpp::NumericVector inferno_green = {
    0.000466127766, 0.00126992553, 0.00224934863, 0.00339180156,
    0.00469194561, 0.00613611626, 0.00771344131, 0.00941675403, 0.0112247138,
    0.0131362262, 0.0151325789, 0.0171991484, 0.0193306298, 0.0215030771,
    0.0237024271, 0.0259207864, 0.0281385015, 0.0303236129, 0.0324736172,
    0.0345691867, 0.0365900213, 0.0385036268, 0.0402939095, 0.0419053329,
    0.0433278666, 0.0445561662, 0.0455829503, 0.0464018731, 0.0470080541,
    0.0473986708, 0.047573592, 0.0475360183, 0.0472930838, 0.0468563678,
    0.0462422566, 0.0454676444, 0.0445588056, 0.0435542881, 0.0424893149,
    0.0414017089, 0.0403288858, 0.0393088888, 0.0384001825, 0.0376322609,
    0.0370296488, 0.0366146049, 0.0364049901, 0.0364052511, 0.0366209949,
    0.0370545017, 0.0377052832, 0.0385706153, 0.0396468666, 0.0409215821,
    0.0423528741, 0.0439325787, 0.0456437598, 0.0474700293, 0.0493958927,
    0.0514069729, 0.0534901321, 0.0556335178, 0.0578265505, 0.0600598734,
    0.0623252772, 0.06461561, 0.0669246832, 0.0692471753, 0.0715785403,
    0.0739149211, 0.0762530701, 0.0785914864, 0.0809267058, 0.0832568129,
    0.0855803445, 0.0878961593, 0.0902033992, 0.0925014543, 0.0947899342,
    0.0970686417, 0.099337551, 0.101597079, 0.103847716, 0.106089165,
    0.108321923, 0.110546584, 0.112763831, 0.11497443, 0.117179219,
    0.119379132, 0.121575414, 0.123768654, 0.125959947, 0.128150439,
    0.130341324, 0.132533845, 0.134729286, 0.136928959, 0.139134147,
    0.141346265, 0.143566769, 0.14579715, 0.148038934, 0.150293679,
    0.152562977, 0.154848232, 0.157151161, 0.159473549, 0.161817111,
    0.164183582, 0.166574724, 0.168992314, 0.17143815, 0.173913876,
    0.176421271, 0.178962399, 0.181539111, 0.184153268, 0.186806728,
    0.189501352, 0.192238994, 0.1950215, 0.197850703, 0.200728196,
    0.203656029, 0.206635993, 0.209669834, 0.21275927, 0.215905976,
    0.219111589, 0.222377697, 0.225705837, 0.229097492, 0.232554083,
    0.236076967, 0.239667435, 0.24332672, 0.247055968, 0.250856232,
    0.254728485, 0.25867361, 0.262692401, 0.266785558, 0.270953688,
    0.2751973, 0.279516805, 0.283912516, 0.288384647, 0.292933312,
    0.297558528, 0.302260213, 0.307038188, 0.311892183, 0.316821833,
    0.321826685, 0.326906201, 0.33205976, 0.337286663, 0.342586137,
    0.34795734, 0.353399363, 0.35891124, 0.364491949, 0.370140419,
    0.375855533, 0.381636138, 0.387481044, 0.393389034, 0.399358867,
    0.405389282, 0.411479007, 0.417626756, 0.423831237, 0.430091162,
    0.436405243, 0.442772199, 0.449190757, 0.455659658, 0.462177656,
    0.468743522, 0.475356048, 0.482014044, 0.488716345, 0.495461806,
    0.502249309, 0.509077761, 0.515946092, 0.522853259, 0.529798246,
    0.536780059, 0.543797733, 0.550850323, 0.557936911, 0.5650566,
    0.572208516, 0.579391803, 0.586605627, 0.593849168, 0.601121626,
    0.608422211, 0.615750147, 0.623104667, 0.630485011, 0.637890424,
    0.645320152, 0.652773439, 0.660249526, 0.667747641, 0.675267,
    0.682806802, 0.690366218, 0.697944391, 0.705540424, 0.713153375,
    0.72078246, 0.728427497, 0.736086521, 0.743758326, 0.751441596,
    0.759134892, 0.766836624, 0.774545028, 0.782258138, 0.789973753,
    0.797691563, 0.805409333, 0.813121725, 0.820825143, 0.828515491,
    0.836190976, 0.843848069, 0.85147634, 0.859068716, 0.866624355,
    0.874128569, 0.881568926, 0.888942277, 0.896225909, 0.903409063,
    0.910472964, 0.917399053, 0.924168246, 0.930760752, 0.937158971,
    0.943347775, 0.949317522, 0.9550629, 0.960586693, 0.965895868,
    0.97100333, 0.975924241, 0.980678193, 0.985282161, 0.989753437,
    0.994108844, 0.998364143
  };

  const Rcpp::NumericVector inferno_blue = {
    0.01386552, 0.018570352, 0.0242390508, 0.0309092475, 0.038557898,
    0.0468360336, 0.0551430756, 0.063459808, 0.071861689, 0.0802817951,
    0.0887668094, 0.0973274383, 0.105929835, 0.114621328, 0.123397286,
    0.132232108, 0.141140519, 0.150163867, 0.159254277, 0.168413539,
    0.177642172, 0.186961588, 0.196353558, 0.205798788, 0.215289113,
    0.224813479, 0.234357604, 0.2439037, 0.2534303, 0.262912235,
    0.272320803, 0.28162417, 0.290788012, 0.299776404, 0.30855291,
    0.317085139, 0.325338414, 0.333276678, 0.340874188, 0.348110606,
    0.354971391, 0.361446945, 0.367534629, 0.373237557, 0.378563264,
    0.383522415, 0.388128944, 0.39240015, 0.396353388, 0.400006615,
    0.403377897, 0.406485031, 0.409345373, 0.411976086, 0.414392106,
    0.416607861, 0.418636756, 0.420491164, 0.422182449, 0.423720999,
    0.425116277, 0.426376869, 0.427510546, 0.42852432, 0.429424503,
    0.430216765, 0.430906186, 0.431497309, 0.431994185, 0.432400419,
    0.432719214, 0.432954973, 0.433108763, 0.433182647, 0.433178526,
    0.433098056, 0.432942678, 0.432713635, 0.432411996, 0.432038673,
    0.431594438, 0.431080497, 0.430497898, 0.429845789, 0.429124507,
    0.42833432, 0.427475431, 0.426547991, 0.425552106, 0.424487908,
    0.42335611, 0.422155676, 0.420886594, 0.419548848, 0.418142411,
    0.416667258, 0.415123366, 0.413510662, 0.411828882, 0.410078028,
    0.408258132, 0.406369246, 0.404411444, 0.402384829, 0.400289528,
    0.398124897, 0.395891308, 0.393589349, 0.391219295, 0.388781456,
    0.38627618, 0.383703854, 0.381064906, 0.378358969, 0.375586209,
    0.372748214, 0.369845599, 0.366879025, 0.363849195, 0.360756856,
    0.357602797, 0.354387853, 0.3511129, 0.347776863, 0.344382594,
    0.340931208, 0.337423766, 0.333861367, 0.330245147, 0.326576275,
    0.322855952, 0.31908541, 0.31526591, 0.311398734, 0.307485188,
    0.303526312, 0.299522665, 0.295476756, 0.291389943, 0.287263585,
    0.283099033, 0.278897629, 0.274660698, 0.270389545, 0.266085445,
    0.261749643, 0.257383341, 0.2529877, 0.248563825, 0.244112767,
    0.239635512, 0.235132978, 0.230606009, 0.226055368, 0.221481734,
    0.216885699, 0.212267762, 0.207628326, 0.202967696, 0.19828608,
    0.193583583, 0.188860212, 0.184115876, 0.179350388, 0.174563472,
    0.169754764, 0.164923826, 0.160070152, 0.155193185, 0.150292329,
    0.145366973, 0.140416519, 0.135440416, 0.130438175, 0.12540944,
    0.120354038, 0.115272059, 0.110163947, 0.105030614, 0.0998735931,
    0.0946952268, 0.0894989073, 0.0842893891, 0.0790731907, 0.0738591143,
    0.0686589199, 0.0634881971, 0.058367489, 0.0533237243, 0.048392009,
    0.0436177922, 0.0390500131, 0.0349306227, 0.0314091591, 0.0285075931,
    0.0262497353, 0.0246613416, 0.0237702263, 0.0236063833, 0.0242021174,
    0.0255921853, 0.0278139496, 0.0309075459, 0.0349160639, 0.0398857472,
    0.0455808037, 0.0517503867, 0.0583286889, 0.0652570167, 0.072489233,
    0.0799897176, 0.0877314215, 0.0956941797, 0.103863324, 0.112228756,
    0.120784651, 0.129526579, 0.138453063, 0.147564573, 0.156863224,
    0.166352544, 0.176037298, 0.185923357, 0.196017589, 0.206331925,
    0.216876839, 0.227658046, 0.238685942, 0.249971582, 0.261533898,
    0.273391112, 0.285545675, 0.298010219, 0.310820466, 0.323973947,
    0.337475479, 0.351368713, 0.365627005, 0.380271225, 0.395289169,
    0.410665194, 0.426373236, 0.442367495, 0.458591507, 0.474969778,
    0.491426053, 0.507859649, 0.524203026, 0.540360752, 0.55627509,
    0.571925382, 0.587205773, 0.60215433, 0.616760413, 0.631017009,
    0.644924005
  };

  const Rcpp::List inferno = Rcpp::List::create(
    Rcpp::_["r"] = inferno_red,
    Rcpp::_["g"] = inferno_green,
    Rcpp::_["b"] = inferno_blue
  );

} // namespace palette
} // namepsace colourvalues

#endif

==> colourvalues_0.3.9.tar.gz: colourvalues/inst/include/colourvalues/palettes/inferno.hpp <==
#ifndef R_COLOURVALUES_INFERNO_H
#define R_COLOURVALUES_INFERNO_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector inferno_red = {
    0.00146159096, 0.00226726368, 0.00329899092, 0.00454690615,
    0.00600552565, 0.00767578856, 0.00956051094, 0.0116634769, 0.0139950388,
    0.0165605595, 0.0193732295, 0.0224468865, 0.0257927373, 0.0294324251,
    0.0333852235, 0.0376684211, 0.0422525554, 0.0469146287, 0.0516437624,
    0.0564491009, 0.06133972, 0.066331262, 0.0714289181, 0.076636756,
    0.0819620773, 0.0874113897, 0.0929901526, 0.0987024972, 0.104550936,
    0.110536084, 0.116656423, 0.122908126, 0.129284984, 0.13577845,
    0.142377819, 0.149072957, 0.155849711, 0.162688939, 0.169575148,
    0.176493202, 0.183428775, 0.190367453, 0.197297425, 0.204209298,
    0.211095463, 0.217948648, 0.224762908, 0.231538148, 0.238272961,
    0.244966911, 0.251620354, 0.258234265, 0.264809649, 0.271346664,
    0.277849829, 0.284321318, 0.290763373, 0.297178251, 0.303568182,
    0.309935342, 0.316281835, 0.322609671, 0.328920763, 0.335216916,
    0.341499828, 0.347771086, 0.354032169, 0.360284449, 0.366529195,
    0.372767575, 0.379000659, 0.385228383, 0.391452659, 0.397674379,
    0.403894278, 0.410113015, 0.416331169, 0.422549249, 0.428767696,
    0.434986885, 0.441207124, 0.447428382, 0.453650614, 0.459874623,
    0.466100494, 0.472328255, 0.478557889, 0.484789325, 0.491022448,
    0.497257069, 0.503492698, 0.509729541, 0.515967304, 0.522205646,
    0.528444192, 0.534682523, 0.540920186, 0.547156706, 0.553391649,
    0.559624442, 0.565854477, 0.572081108, 0.578303656, 0.584521407,
    0.590733615, 0.596939751, 0.60313893, 0.609330184, 0.615512627,
    0.62168534, 0.627847374, 0.633997746, 0.640135447, 0.646259648,
    0.652369348, 0.658463166, 0.664539964, 0.670598572, 0.676637795,
    0.682656407, 0.688653158, 0.694626769, 0.700575937, 0.706499709,
    0.712396345, 0.718264447, 0.724102613, 0.729909422, 0.735683432,
    0.741423185, 0.747127207, 0.752794009, 0.75842209, 0.76400994,
    0.769556038, 0.775058888, 0.780517023, 0.785928794, 0.791292674,
    0.796607144, 0.801870689, 0.807081807, 0.812239008, 0.817340818,
    0.822385784, 0.827372474, 0.832299481, 0.837165425, 0.841968959,
    0.846708768, 0.851383572, 0.85599213, 0.860533241, 0.865005747,
    0.869408534, 0.87374053, 0.878000715, 0.882188112, 0.886301795,
    0.890340885, 0.894304553, 0.898192017, 0.902002544, 0.905735448,
    0.90939009, 0.912965874, 0.916462251, 0.91987871, 0.923214783,
    0.926470039, 0.929644083, 0.932736555, 0.935747126, 0.938675494,
    0.941521384, 0.944284543, 0.946964741, 0.949561766, 0.952075421,
    0.954505523, 0.956851903, 0.959114397, 0.96129285, 0.96338711,
    0.965397031, 0.967322465, 0.969163264, 0.970919277, 0.972590351,
    0.974176327, 0.975677038, 0.977092313, 0.978421971, 0.979665824,
    0.980823673, 0.981895311, 0.982880522, 0.983779081, 0.984590755,
    0.985315301, 0.985952471, 0.986502013, 0.98696367, 0.987337182,
    0.987622296, 0.987818759, 0.98792633, 0.987944783, 0.98787391,
    0.987713535, 0.987463516, 0.987123759, 0.986694229, 0.98617497,
    0.985565739, 0.984865203, 0.984075129, 0.983195992, 0.982228463,
    0.981173457, 0.980032178, 0.978806183, 0.977497453, 0.976108474,
    0.974637842, 0.973087939, 0.971467822, 0.969783146, 0.968040817,
    0.966242589, 0.964393924, 0.962516656, 0.960625545, 0.958720088,
    0.956834075, 0.954997177, 0.953215092, 0.951546225, 0.950018481,
    0.948683391, 0.947594362, 0.946809163, 0.946391536, 0.946402951,
    0.946902568, 0.947936825, 0.94954483, 0.951740304, 0.954529281,
    0.957896053, 0.96181202, 0.966248822, 0.971161622, 0.976510983,
    0.982257307, 0.988362068
  };

  const Rcpp::NumericVector inferno_green = {
    0.000466127766, 0.00126992553, 0.00224934863, 0.00339180156,
    0.00469194561, 0.00613611626, 0.00771344131, 0.00941675403, 0.0112247138,
    0.0131362262, 0.0151325789, 0.0171991484, 0.0193306298, 0.0215030771,
    0.0237024271, 0.0259207864, 0.0281385015, 0.0303236129, 0.0324736172,
    0.0345691867, 0.0365900213, 0.0385036268, 0.0402939095, 0.0419053329,
    0.0433278666, 0.0445561662, 0.0455829503, 0.0464018731, 0.0470080541,
    0.0473986708, 0.047573592, 0.0475360183, 0.0472930838, 0.0468563678,
    0.0462422566, 0.0454676444, 0.0445588056, 0.0435542881, 0.0424893149,
    0.0414017089, 0.0403288858, 0.0393088888, 0.0384001825, 0.0376322609,
    0.0370296488, 0.0366146049, 0.0364049901, 0.0364052511, 0.0366209949,
    0.0370545017, 0.0377052832, 0.0385706153, 0.0396468666, 0.0409215821,
    0.0423528741, 0.0439325787, 0.0456437598, 0.0474700293, 0.0493958927,
    0.0514069729, 0.0534901321, 0.0556335178, 0.0578265505, 0.0600598734,
    0.0623252772, 0.06461561, 0.0669246832, 0.0692471753, 0.0715785403,
    0.0739149211, 0.0762530701, 0.0785914864, 0.0809267058, 0.0832568129,
    0.0855803445, 0.0878961593, 0.0902033992, 0.0925014543, 0.0947899342,
    0.0970686417, 0.099337551, 0.101597079, 0.103847716, 0.106089165,
    0.108321923, 0.110546584, 0.112763831, 0.11497443, 0.117179219,
    0.119379132, 0.121575414, 0.123768654, 0.125959947, 0.128150439,
    0.130341324, 0.132533845, 0.134729286, 0.136928959, 0.139134147,
    0.141346265, 0.143566769, 0.14579715, 0.148038934, 0.150293679,
    0.152562977, 0.154848232, 0.157151161, 0.159473549, 0.161817111,
    0.164183582, 0.166574724, 0.168992314, 0.17143815, 0.173913876,
    0.176421271, 0.178962399, 0.181539111, 0.184153268, 0.186806728,
    0.189501352, 0.192238994, 0.1950215, 0.197850703, 0.200728196,
    0.203656029, 0.206635993, 0.209669834, 0.21275927, 0.215905976,
    0.219111589, 0.222377697, 0.225705837, 0.229097492, 0.232554083,
    0.236076967, 0.239667435, 0.24332672, 0.247055968, 0.250856232,
    0.254728485, 0.25867361, 0.262692401, 0.266785558, 0.270953688,
    0.2751973, 0.279516805, 0.283912516, 0.288384647, 0.292933312,
    0.297558528, 0.302260213, 0.307038188, 0.311892183, 0.316821833,
    0.321826685, 0.326906201, 0.33205976, 0.337286663, 0.342586137,
    0.34795734, 0.353399363, 0.35891124, 0.364491949, 0.370140419,
    0.375855533, 0.381636138, 0.387481044, 0.393389034, 0.399358867,
    0.405389282, 0.411479007, 0.417626756, 0.423831237, 0.430091162,
    0.436405243, 0.442772199, 0.449190757, 0.455659658, 0.462177656,
    0.468743522, 0.475356048, 0.482014044, 0.488716345, 0.495461806,
    0.502249309, 0.509077761, 0.515946092, 0.522853259, 0.529798246,
    0.536780059, 0.543797733, 0.550850323, 0.557936911, 0.5650566,
    0.572208516, 0.579391803, 0.586605627, 0.593849168, 0.601121626,
    0.608422211, 0.615750147, 0.623104667, 0.630485011, 0.637890424,
    0.645320152, 0.652773439, 0.660249526, 0.667747641, 0.675267,
    0.682806802, 0.690366218, 0.697944391, 0.705540424, 0.713153375,
    0.72078246, 0.728427497, 0.736086521, 0.743758326, 0.751441596,
    0.759134892, 0.766836624, 0.774545028, 0.782258138, 0.789973753,
    0.797691563, 0.805409333, 0.813121725, 0.820825143, 0.828515491,
    0.836190976, 0.843848069, 0.85147634, 0.859068716, 0.866624355,
    0.874128569, 0.881568926, 0.888942277, 0.896225909, 0.903409063,
    0.910472964, 0.917399053, 0.924168246, 0.930760752, 0.937158971,
    0.943347775, 0.949317522, 0.9550629, 0.960586693, 0.965895868,
    0.97100333, 0.975924241, 0.980678193, 0.985282161, 0.989753437,
    0.994108844, 0.998364143
  };

  const Rcpp::NumericVector inferno_blue = {
    0.01386552, 0.018570352, 0.0242390508, 0.0309092475, 0.038557898,
    0.0468360336, 0.0551430756, 0.063459808, 0.071861689, 0.0802817951,
    0.0887668094, 0.0973274383, 0.105929835, 0.114621328, 0.123397286,
    0.132232108, 0.141140519, 0.150163867, 0.159254277, 0.168413539,
    0.177642172, 0.186961588, 0.196353558, 0.205798788, 0.215289113,
    0.224813479, 0.234357604, 0.2439037, 0.2534303, 0.262912235,
    0.272320803, 0.28162417, 0.290788012, 0.299776404, 0.30855291,
    0.317085139, 0.325338414, 0.333276678, 0.340874188, 0.348110606,
    0.354971391, 0.361446945, 0.367534629, 0.373237557, 0.378563264,
    0.383522415, 0.388128944, 0.39240015, 0.396353388, 0.400006615,
    0.403377897, 0.406485031, 0.409345373, 0.411976086, 0.414392106,
    0.416607861, 0.418636756, 0.420491164, 0.422182449, 0.423720999,
    0.425116277, 0.426376869, 0.427510546, 0.42852432, 0.429424503,
    0.430216765, 0.430906186, 0.431497309, 0.431994185, 0.432400419,
    0.432719214, 0.432954973, 0.433108763, 0.433182647, 0.433178526,
    0.433098056, 0.432942678, 0.432713635, 0.432411996, 0.432038673,
    0.431594438, 0.431080497, 0.430497898, 0.429845789, 0.429124507,
    0.42833432, 0.427475431, 0.426547991, 0.425552106, 0.424487908,
    0.42335611, 0.422155676, 0.420886594, 0.419548848, 0.418142411,
    0.416667258, 0.415123366, 0.413510662, 0.411828882, 0.410078028,
    0.408258132, 0.406369246, 0.404411444, 0.402384829, 0.400289528,
    0.398124897, 0.395891308, 0.393589349, 0.391219295, 0.388781456,
    0.38627618, 0.383703854, 0.381064906, 0.378358969, 0.375586209,
    0.372748214, 0.369845599, 0.366879025, 0.363849195, 0.360756856,
    0.357602797, 0.354387853, 0.3511129, 0.347776863, 0.344382594,
    0.340931208, 0.337423766, 0.333861367, 0.330245147, 0.326576275,
    0.322855952, 0.31908541, 0.31526591, 0.311398734, 0.307485188,
    0.303526312, 0.299522665, 0.295476756, 0.291389943, 0.287263585,
    0.283099033, 0.278897629, 0.274660698, 0.270389545, 0.266085445,
    0.261749643, 0.257383341, 0.2529877, 0.248563825, 0.244112767,
    0.239635512, 0.235132978, 0.230606009, 0.226055368, 0.221481734,
    0.216885699, 0.212267762, 0.207628326, 0.202967696, 0.19828608,
    0.193583583, 0.188860212, 0.184115876, 0.179350388, 0.174563472,
    0.169754764, 0.164923826, 0.160070152, 0.155193185, 0.150292329,
    0.145366973, 0.140416519, 0.135440416, 0.130438175, 0.12540944,
    0.120354038, 0.115272059, 0.110163947, 0.105030614, 0.0998735931,
    0.0946952268, 0.0894989073, 0.0842893891, 0.0790731907, 0.0738591143,
    0.0686589199, 0.0634881971, 0.058367489, 0.0533237243, 0.048392009,
    0.0436177922, 0.0390500131, 0.0349306227, 0.0314091591, 0.0285075931,
    0.0262497353, 0.0246613416, 0.0237702263, 0.0236063833, 0.0242021174,
    0.0255921853, 0.0278139496, 0.0309075459, 0.0349160639, 0.0398857472,
    0.0455808037, 0.0517503867, 0.0583286889, 0.0652570167, 0.072489233,
    0.0799897176, 0.0877314215, 0.0956941797, 0.103863324, 0.112228756,
    0.120784651, 0.129526579, 0.138453063, 0.147564573, 0.156863224,
    0.166352544, 0.176037298, 0.185923357, 0.196017589, 0.206331925,
    0.216876839, 0.227658046, 0.238685942, 0.249971582, 0.261533898,
    0.273391112, 0.285545675, 0.298010219, 0.310820466, 0.323973947,
    0.337475479, 0.351368713, 0.365627005, 0.380271225, 0.395289169,
    0.410665194, 0.426373236, 0.442367495, 0.458591507, 0.474969778,
    0.491426053, 0.507859649, 0.524203026, 0.540360752, 0.55627509,
    0.571925382, 0.587205773, 0.60215433, 0.616760413, 0.631017009,
    0.644924005
  };

  // const Rcpp::List inferno = Rcpp::List::create(
  //   Rcpp::_["r"] = inferno_red,
  //   Rcpp::_["g"] = inferno_green,
  //   Rcpp::_["b"] = inferno_blue
  // );

} // namespace palette
} // namepsace colourvalues

#endif
